package edu.ncsu.csc.itrust.UC20;

import java.util.List;
import java.util.ArrayList;
import java.sql.Date;

import junit.framework.TestCase;
import edu.ncsu.csc.itrust.dao.mysql.CauseOfDeathTrendsReportDAO;
import edu.ncsu.csc.itrust.unit.datagenerators.TestDataGenerator;
import edu.ncsu.csc.itrust.unit.testutils.TestDAOFactory;
import edu.ncsu.csc.itrust.exception.DBException;


public class CauseOfDeathTrendsReportTest extends TestCase {
    
    private TestDataGenerator gen = new TestDataGenerator();
    private CauseOfDeathTrendsReportDAO cod;
    
    @Override
	protected void setUp() throws Exception {
		gen = new TestDataGenerator();
		gen.clearAllTables();
		gen.deadpatient1();
        gen.deadpatient2();
        gen.deadpatient3();
        gen.deadpatient4();
        gen.deadpatient5();
        gen.deadpatient6();
        gen.deadpatient7();
        gen.deadpatient8();
        gen.deadpatient9();
        gen.deadpatient10();
        gen.icd9cmCodes();

        cod = new CauseOfDeathTrendsReportDAO(TestDAOFactory.getTestInstance());
    }
    
    public void testPatientsForHCPValid() throws Exception {
        List<Long> deaths = cod.getPatientsForHCP(Long.parseLong("9000000000"));
        assertEquals(6, deaths.size());
        assertEquals(Long.valueOf(81), deaths.get(0));
        assertEquals(Long.valueOf(82), deaths.get(1));
        assertEquals(Long.valueOf(83), deaths.get(2));
        assertEquals(Long.valueOf(84), deaths.get(3));
        assertEquals(Long.valueOf(85), deaths.get(4));
        assertEquals(Long.valueOf(86), deaths.get(5));
    }

    /*public void testPatientsForHCPInvalidID() throws Exception {
		try {
			cod.getPatientsForHCP(Long("0"));
			fail("Should have failed but didn't");
		} catch (FormValidationException e) {
			assertEquals(1, e.getErrorList().size());
			assertEquals("HCP ID must be valid!", e.getErrorList().get(0));
		}
    }
    */

    public void testTopTwoCorrectForHCPValid() throws Exception {
        List<String> deaths = cod.getTopTwoDeathsForHCP(Long.parseLong("9000000000"), "All", Date.valueOf("2018-01-01"), Date.valueOf("2020-12-31"));
        assertEquals(2, deaths.size());
        assertEquals("Name: Tuberculosis of the lung, Code: 11.40, Deaths: 3", deaths.get(0));
        assertEquals("Name: Malaria, Code: 84.50, Deaths: 2", deaths.get(1));
    }

    public void testTopTwoCorrectMaleForHCPValid() throws Exception {
        List<String> deaths = cod.getTopTwoDeathsForHCP(Long.parseLong("9000000000"), "Male", Date.valueOf("2018-01-01"), Date.valueOf("2020-12-31"));
        assertEquals(2, deaths.size());
        assertEquals("Name: Malaria, Code: 84.50, Deaths: 2", deaths.get(0));
        assertEquals("Name: Tuberculosis of the lung, Code: 11.40, Deaths: 2", deaths.get(1));
    }

    /*public void testTopTwoCorrectForAllValid() throws Exception {
        List<String> deaths = cod.getTopTwoDeathsForAll("All", Date.valueOf("2018-01-01"), Date.valueOf("2020-12-31"));
        assertEquals(2, deaths.size());
        assertEquals("Name: Influenza, Code: 487.00, Deaths: 5", deaths.get(0));
        assertEquals("Name: Tuberculosis of the lung, Code: 11.40, Deaths: 3", deaths.get(1));
    }*/

    public void testCodeNameExists() throws Exception {
        String deaths = cod.getCodeName("84.50");
        assertEquals("Malaria", deaths);
    }

    public void testCodeNameDoesNotExist() throws Exception {
        String deaths = cod.getCodeName("8450");
        assertEquals(null, deaths);
    }
}